package com.ruoyi.web.controller.board;

import com.ruoyi.board.domain.PlanType;
import com.ruoyi.board.service.IPlanTypeService;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 计划发布中的类型Controller
 *
 * @author fuhao
 * @date 2024-09-02
 */
@RestController
@RequestMapping("/plan/type")
public class PlanTypeController extends BaseController {
    @Autowired
    private IPlanTypeService planTypeService;

    /**
     * 查询计划发布中的类型列表
     */
    @PreAuthorize("@ss.hasPermi('plan:type:list')")
    @GetMapping("/list")
    public AjaxResult list(PlanType planType) {
        List<PlanType> list = planTypeService.list();
        return success(list);
    }

    /**
     * 导出计划发布中的类型列表
     */
    @PreAuthorize("@ss.hasPermi('plan:type:export')")
    @Log(title = "计划发布中的类型", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PlanType planType) {
        List<PlanType> list = planTypeService.list();
        ExcelUtil<PlanType> util = new ExcelUtil<PlanType>(PlanType.class);
        util.exportExcel(response, list, "计划发布中的类型数据");
    }

    /**
     * 获取计划发布中的类型详细信息
     */
    @PreAuthorize("@ss.hasPermi('plan:type:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(planTypeService.getById(id));
    }

    /**
     * 新增计划发布中的类型
     */
    @PreAuthorize("@ss.hasPermi('plan:type:add')")
    @Log(title = "计划发布中的类型", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PlanType planType) {
        return toAjax(planTypeService.save(planType));
    }

    /**
     * 修改计划发布中的类型
     */
    @PreAuthorize("@ss.hasPermi('plan:type:edit')")
    @Log(title = "计划发布中的类型", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PlanType planType) {
        return toAjax(planTypeService.saveOrUpdate(planType));
    }

    /**
     * 删除计划发布中的类型
     */
    @PreAuthorize("@ss.hasPermi('plan:type:remove')")
    @Log(title = "计划发布中的类型", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable List<Integer> ids) {
        return toAjax(planTypeService.removeByIds(ids));
    }


    /**
     * 获取类型树列表
     */
    @PreAuthorize("@ss.hasPermi('plan:type:list')")
    @GetMapping("/planTree")
    public AjaxResult deptTree(PlanType planType) {
        return success(planTypeService.listPlanTree(planType));
    }
}
